@@ -1,6 +1,6 @@
 package NetHack::Item;
-BEGIN {
-  $NetHack::Item::VERSION = '0.13';
+{
+  $NetHack::Item::VERSION = '0.14';
 }
 use 5.008001;
 use Moose -traits => 'NetHack::Item::Meta::Trait::InstallsSpoilers';
@@ -249,7 +249,7 @@ sub extract_stats {
     my @fields = qw/slot quantity buc greased poisoned erosion1 erosion2 proofed
                     used eaten diluted enchantment item generic specific
                     recharges charges candles lit_candelabrum lit laid chained
-                    quivered offhand offhand_wielded wielded worn cost altcost/;
+                    quivered offhand offhand_wielded wielded worn cost cost2 cost3/;
 
     # the \b in front of "item name" forbids "Amulet of Yendor" being parsed as
     # "A mulet of Yendor"
@@ -282,10 +282,12 @@ sub extract_stats {
         (\((?:weapon|wielded).*?\))?                      \s*  # wielding
         (\((?:being|embedded|on).*?\))?                   \s*  # worn
 
-        # shop cost! there are two forms, with an optional quality comment
+        # shop cost! there are multiple forms, with an optional quality comment
         (?:
             \( unpaid, \  (\d+) \  zorkmids? \)
             |
+            \( (\d+) \  zorkmids? \)
+            |
             ,\ no\ charge (?:,\ .*)?
             |
             ,\ (?:price\ )? (\d+) \  zorkmids (\ each)? (?:,\ .*)?
@@ -351,8 +353,11 @@ sub extract_stats {
         $stats{$_} = defined($stats{$_}) ? 1 : undef;
     }
 
-    my $altcost = delete $stats{altcost};
-    $stats{cost} ||= $altcost;
+    my $cost2 = delete $stats{cost2};
+    $stats{cost} ||= $cost2;
+
+    my $cost3 = delete $stats{cost3};
+    $stats{cost} ||= $cost3;
 
     # numeric, undef = 0 stats
     for (qw/candles cost/) {
@@ -705,7 +710,7 @@ NetHack::Item - parse and interact with a NetHack item
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -824,4 +829,4 @@ Copyright 2009-2011 Shawn M Moore.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
